==> haskell-regex-applicative-0.3.4-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-FcoDosV2cDR9zgx3DwTKwr
key:                  regex-applicative-0.3.4-FcoDosV2cDR9zgx3DwTKwr
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  63c75aae4a24552de365a57479c1062c
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative
hs-libraries:         HSregex-applicative-0.3.4-FcoDosV2cDR9zgx3DwTKwr
depends:
    base-4.17.2.1 containers-0.6.7
    filtrable-0.1.6.0-FylDJRqxkLa8obRp03IlyM transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.4-217-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-LokRlkCGLgF4DE3uudF4MZ
key:                  regex-applicative-0.3.4-LokRlkCGLgF4DE3uudF4MZ
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  95d572ea8cb46d97c372743013087f24
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative
hs-libraries:         HSregex-applicative-0.3.4-LokRlkCGLgF4DE3uudF4MZ
depends:
    base-4.17.2.1 containers-0.6.7
    filtrable-0.1.6.0-969Hhv73w2rKQNDimb3rVk transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
